@@ -1,9 +1,9 @@
 package Hobocamp;
-BEGIN {
-  $Hobocamp::VERSION = '0.501';
+{
+  $Hobocamp::VERSION = '0.600';
 }
 
-use v5.12.2;
+use v5.10;
 use warnings;
 
 # ABSTRACT: Moose-based interface to dialog (simple text based GUI)
@@ -69,7 +69,7 @@ Hobocamp - Moose-based interface to dialog (simple text based GUI)
 
 =head1 VERSION
 
-version 0.501
+version 0.600
 
 =head1 SYNOPSIS
 
