@@ -1,9 +1,9 @@
 package Hobocamp::Calendar;
-BEGIN {
-  $Hobocamp::Calendar::VERSION = '0.501';
+{
+  $Hobocamp::Calendar::VERSION = '0.600';
 }
 
-use v5.12.2;
+use v5.10;
 use warnings;
 
 # ABSTRACT: calendar widget
@@ -54,7 +54,7 @@ Hobocamp::Calendar - calendar widget
 
 =head1 VERSION
 
-version 0.501
+version 0.600
 
 =head1 DESCRIPTION
 
