@@ -1,9 +1,9 @@
 package Hobocamp::DirectorySelect;
-BEGIN {
-  $Hobocamp::DirectorySelect::VERSION = '0.501';
+{
+  $Hobocamp::DirectorySelect::VERSION = '0.600';
 }
 
-use v5.12.2;
+use v5.10;
 use warnings;
 
 # ABSTRACT: Widget to select a directory
@@ -42,7 +42,7 @@ Hobocamp::DirectorySelect - Widget to select a directory
 
 =head1 VERSION
 
-version 0.501
+version 0.600
 
 =head1 DESCRIPTION
 
