@@ -1,9 +1,9 @@
 package Hobocamp::InputBox;
-BEGIN {
-  $Hobocamp::InputBox::VERSION = '0.501';
+{
+  $Hobocamp::InputBox::VERSION = '0.600';
 }
 
-use v5.12.2;
+use v5.10;
 use warnings;
 
 # ABSTRACT: text input widget
@@ -49,7 +49,7 @@ Hobocamp::InputBox - text input widget
 
 =head1 VERSION
 
-version 0.501
+version 0.600
 
 =head1 DESCRIPTION
 
