@@ -1,9 +1,9 @@
 package Hobocamp::MessageBox;
-BEGIN {
-  $Hobocamp::MessageBox::VERSION = '0.501';
+{
+  $Hobocamp::MessageBox::VERSION = '0.600';
 }
 
-use v5.12.2;
+use v5.10;
 use warnings;
 
 # ABSTRACT: Message box widget
@@ -44,7 +44,7 @@ Hobocamp::MessageBox - Message box widget
 
 =head1 VERSION
 
-version 0.501
+version 0.600
 
 =head1 DESCRIPTION
 
