@@ -1,9 +1,9 @@
 package Hobocamp::YesNo;
-BEGIN {
-  $Hobocamp::YesNo::VERSION = '0.501';
+{
+  $Hobocamp::YesNo::VERSION = '0.600';
 }
 
-use v5.12.2;
+use v5.10;
 use warnings;
 
 # ABSTRACT: yes or no prompt
@@ -36,7 +36,7 @@ Hobocamp::YesNo - yes or no prompt
 
 =head1 VERSION
 
-version 0.501
+version 0.600
 
 =head1 DESCRIPTION
 
